==> boinc_6.12.33+dfsg.orig.tar.gz: boinc-6.12.33+dfsg/html/user/host_app_versions.php <==
<?php

require_once("../inc/util.inc");

function rsc_name($t) {
    switch ($t) {
    case 2: return "CPU";
    case 3: return "nvidia GPU";
    case 4: return "ATI GPU";
    }
    return "Unknown";
}

function av_desc($gavid) {
    if ($gavid >= 1000000) {
        $appid = (int)($gavid/1000000);
        $app = BoincApp::lookup_id($appid);
        if (!$app) return "Anonymous platform, missing app";
        $rsc_type = $gavid % 1000000;
        $r = rsc_name($rsc_type);
        return "$app->user_friendly_name (anonymous platform, $r)";

    } else {
        $av = BoincAppVersion::lookup_id($gavid);
        if (!$av) return "Missing app version";
        $app = BoincApp::lookup_id($av->appid);
        if (!$app) return "Missing app";
        $platform = BoincPlatform::lookup_id($av->platformid);
        if (!$platform) return "Missing platform";
        $pc = (strlen($av->plan_class))?"($av->plan_class)":"";
        $v = number_format($av->version_num/100, 2);
        return "$app->user_friendly_name $v $platform->name $pc";
    }
}

function show_hav($hav) {
    row1(av_desc($hav->app_version_id));
    row2("Number of tasks completed", $hav->pfc_n);
    row2("Max tasks per day", $hav->max_jobs_per_day);
    row2("Number of tasks today", $hav->n_jobs_today);
    row2("Consecutive valid tasks", $hav->consecutive_valid);
    $x = number_format($hav->turnaround_avg/86400, 2);
    if ($hav->et_avg) {
        $gflops = 1e-9/$hav->et_avg;
        row2("Average processing rate", $gflops);
    }
    row2("Average turnaround time", "$x days");
}

$hostid = get_int('hostid');

$havs = BoincHostAppVersion::enum("host_id=$hostid");

page_head(tra("Application details for host %1", $hostid));
start_table();
foreach ($havs as $hav) {
    //if (!$hav->pfc_n) continue;
    show_hav($hav);
}
end_table();

page_tail();
?>

==> boinc_6.13.1+dfsg.orig.tar.gz: boinc-6.13.1+dfsg/html/user/host_app_versions.php <==
<?php
// This file is part of BOINC.
// http://boinc.berkeley.edu
// Copyright (C) 2011 University of California
//
// BOINC is free software; you can redistribute it and/or modify it
// under the terms of the GNU Lesser General Public License
// as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// BOINC is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with BOINC.  If not, see <http://www.gnu.org/licenses/>.

require_once("../inc/util.inc");

check_get_args(array("hostid"));

function rsc_name($t) {
    switch ($t) {
    case 2: return "CPU";
    case 3: return "nvidia GPU";
    case 4: return "ATI GPU";
    }
    return "Unknown";
}

function av_desc($gavid) {
    if ($gavid >= 1000000) {
        $appid = (int)($gavid/1000000);
        $app = BoincApp::lookup_id($appid);
        if (!$app) return "Anonymous platform, missing app";
        $rsc_type = $gavid % 1000000;
        $r = rsc_name($rsc_type);
        return "$app->user_friendly_name (anonymous platform, $r)";

    } else {
        $av = BoincAppVersion::lookup_id($gavid);
        if (!$av) return "Missing app version";
        $app = BoincApp::lookup_id($av->appid);
        if (!$app) return "Missing app";
        $platform = BoincPlatform::lookup_id($av->platformid);
        if (!$platform) return "Missing platform";
        $pc = (strlen($av->plan_class))?"($av->plan_class)":"";
        $v = number_format($av->version_num/100, 2);
        return "$app->user_friendly_name $v $platform->name $pc";
    }
}

function show_hav($hav) {
    row1(av_desc($hav->app_version_id));
    row2("Number of tasks completed", $hav->pfc_n);
    row2("Max tasks per day", $hav->max_jobs_per_day);
    row2("Number of tasks today", $hav->n_jobs_today);
    row2("Consecutive valid tasks", $hav->consecutive_valid);
    $x = number_format($hav->turnaround_avg/86400, 2);
    if ($hav->et_avg) {
        $gflops = 1e-9/$hav->et_avg;
        row2("Average processing rate", $gflops);
    }
    row2("Average turnaround time", "$x days");
}

$hostid = get_int('hostid');

$havs = BoincHostAppVersion::enum("host_id=$hostid");

page_head(tra("Application details for host %1", $hostid));
start_table();
foreach ($havs as $hav) {
    //if (!$hav->pfc_n) continue;
    show_hav($hav);
}
end_table();

page_tail();
?>
